searchData={"items":[{"type":"module","title":"Wiki.Action","doc":"Adapter to the MediaWiki [Action API](https://www.mediawiki.org/wiki/Special:MyLanguage/API:Main_page)\n\nMost commands return a pipeable Wiki.Action.Session, which can be reused repeatedly.\n\nAnonymous requests,\n\n```elixir\nWiki.SiteMatrix.new()\n|> Wiki.SiteMatrix.get!(\"dewiki\")\n|> Wiki.Action.new()\n|> Wiki.Action.get!(\n  action: :query,\n  meta: :siteinfo,\n  siprop: :statistics\n)\n# %Wiki.Action.Session{\n#   ...\n#   result: %{\n#     \"batchcomplete\" => true,\n#     \"query\" => %{\n#       \"statistics\" => %{\n#         \"activeusers\" => 19393,\n#         \"admins\" => 188,\n#         \"articles\" => 2583636,\n#         \"edits\" => 211249646,\n#         \"images\" => 130213,\n#         \"jobs\" => 0,\n#         \"pages\" => 7164514,\n#         \"queued-massmessages\" => 0,\n#         \"users\" => 3716049\n#       }\n#     }\n#   },\n#   ...\n# }\n```\n\nCommands can be pipelined while accumulating results, and logged-in user permissions\ndelegated by supplying a [bot password](https://www.mediawiki.org/wiki/Manual:Bot_passwords).\n\n```elixir\nWiki.SiteMatrix.new()\n|> Wiki.SiteMatrix.get!(\"enwiki\")\n|> Wiki.Action.new(\n  accumulate: true\n)\n|> Wiki.Action.authenticate!(\n  Application.get_env(:example_app, :bot_username),\n  Application.get_env(:example_app, :bot_password)\n)\n|> Wiki.Action.get!(\n  action: :query,\n  meta: :tokens,\n  type: :csrf\n)\n|> (&Wiki.Action.post!(&1,\n  action: :edit,\n  title: \"Sandbox\",\n  assert: :user,\n  token: &1.result[\"query\"][\"tokens\"][\"csrftoken\"],\n  appendtext: \"~~~~ was here.\"\n)).()\n|> Map.get(:result)\n```\n\nStreaming results from multiple requests using continuation,\n\n```elixir\nWiki.SiteMatrix.new()\n|> Wiki.SiteMatrix.get!(\"dewiki\")\n|> Wiki.Action.new()\n|> Wiki.Action.stream(\n  action: :query,\n  list: :recentchanges,\n  rclimit: 5\n)\n|> Stream.take(10)\n|> Enum.flat_map(fn response -> response[\"query\"][\"recentchanges\"] end)\n|> Enum.map(fn rc -> rc[\"timestamp\"] <> \" \" <> rc[\"title\"] end)\n```","ref":"Wiki.Action.html"},{"type":"module","title":"Wikibase - Wiki.Action","doc":"The [Wikidata](https://www.wikidata.org/) project provides structured data for\nother wiki projects, and can be accessed through the Action API.\n\nExamples:\n\nSearch for entities called \"alphabet\",\n```elixir\nWiki.SiteMatrix.new()\n|> Wiki.SiteMatrix.get!(\"wikidatawiki\")\n|> Wiki.Action.new()\n|> Wiki.Action.get!(\n    action: :wbsearchentities,\n    search: \"alphabet\",\n    language: :en\n)\n```\n\nSearch for entities with \"Frank Zappa\" anywhere in the description or contents,\n```elixir\nWiki.SiteMatrix.new()\n|> Wiki.SiteMatrix.get!(\"wikidatawiki\")\n|> Wiki.Action.new()\n|> Wiki.Action.get!(\n    action: :wbsearchentities,\n    search: \"alphabet\",\n    language: :en\n)\n```\n\nRetrieve all data about a specific entity with ID \"Q42\",\n```elixir\nWiki.SiteMatrix.new()\n|> Wiki.SiteMatrix.get!(\"wikidatawiki\")\n|> Wiki.Action.new()\n|> Wiki.Action.get!(\n    action: :wbgetentities,\n    ids: \"Q42\"\n)\n```","ref":"Wiki.Action.html#module-wikibase"},{"type":"module","title":"Defaults - Wiki.Action","doc":"A few parameters are automatically added for convenience, but can be\noverridden if desired:\n\n* The `:format` parameter defaults to `:json`.\n* `:formatversion` defaults to `2`.\n\nOverriding to get pretty-printed JSON and the older response structure,\n```elixir\nWiki.Action.get!(\n  action: query,\n  meta: siteinfo,\n  siprop: namespaces,\n  format: jsonfm,\n  formatversion: 1\n)\n```","ref":"Wiki.Action.html#module-defaults"},{"type":"function","title":"Wiki.Action.authenticate/3","doc":"Make requests to authenticate a client session.  This should only be done using\na [bot username and password](https://www.mediawiki.org/wiki/Manual:Bot_passwords),\nwhich can be created for any normal user account.","ref":"Wiki.Action.html#authenticate/3"},{"type":"function","title":"Arguments - Wiki.Action.authenticate/3","doc":"- `session` - Base session pointing to a wiki.\n- `username` - Bot username, may be different than the final logged-in username.\n- `password` - Bot password.  Protect this string, it allows others to take on-wiki actions on your behalf.","ref":"Wiki.Action.html#authenticate/3-arguments"},{"type":"function","title":"Return value - Wiki.Action.authenticate/3","doc":"Authenticated session object.","ref":"Wiki.Action.html#authenticate/3-return-value"},{"type":"function","title":"Wiki.Action.authenticate!/3","doc":"Assertive variant of `authenticate`","ref":"Wiki.Action.html#authenticate!/3"},{"type":"function","title":"Wiki.Action.get/2","doc":"Make an API GET request","ref":"Wiki.Action.html#get/2"},{"type":"function","title":"Arguments - Wiki.Action.get/2","doc":"- `session` - `Wiki.Action.Session` object.\n- `params` - Keyword list of query parameters as atoms or strings.","ref":"Wiki.Action.html#get/2-arguments"},{"type":"function","title":"Return value - Wiki.Action.get/2","doc":"Session object with its `.result` populated.","ref":"Wiki.Action.html#get/2-return-value"},{"type":"function","title":"Wiki.Action.get!/2","doc":"Assertive variant of `get`.","ref":"Wiki.Action.html#get!/2"},{"type":"function","title":"Wiki.Action.new/2","doc":"Create a new client session","ref":"Wiki.Action.html#new/2"},{"type":"function","title":"Arguments - Wiki.Action.new/2","doc":"- `site` - SiteMatrix.Spec or raw `api.php` endpoint for the wiki you will\n  connect to.  For example, \"https://en.wikipedia.org/w/api.php\".\n- `opts` - configuration options which modify client behavior","ref":"Wiki.Action.html#new/2-arguments"},{"type":"function","title":"Wiki.Action.post/2","doc":"Make an API POST request.","ref":"Wiki.Action.html#post/2"},{"type":"function","title":"Arguments - Wiki.Action.post/2","doc":"- `session` - `Wiki.Action.Session` object.  If credentials are required for this\naction, you should have created this object with the `authenticate/3` function.\n- `params` - Keyword list of query parameters as atoms or strings.","ref":"Wiki.Action.html#post/2-arguments"},{"type":"function","title":"Return value - Wiki.Action.post/2","doc":"Session object with a populated `:result` attribute.","ref":"Wiki.Action.html#post/2-return-value"},{"type":"function","title":"Wiki.Action.post!/2","doc":"Assertive variant of `post`.","ref":"Wiki.Action.html#post!/2"},{"type":"function","title":"Wiki.Action.stream/2","doc":"Make a GET request and follow continuations until exhausted or the stream is closed.","ref":"Wiki.Action.html#stream/2"},{"type":"function","title":"Arguments - Wiki.Action.stream/2","doc":"- `session` - `Wiki.Action.Session` object.\n- `params` - Keyword list of query parameters as atoms or strings.","ref":"Wiki.Action.html#stream/2-arguments"},{"type":"function","title":"Return value - Wiki.Action.stream/2","doc":"Enumerable `Stream`, where each returned chunk is a raw result map, possibly\ncontaining multiple records.  This corresponds to `session.result` from the other\nentry points.","ref":"Wiki.Action.html#stream/2-return-value"},{"type":"type","title":"Wiki.Action.client_option/0","doc":"","ref":"Wiki.Action.html#t:client_option/0"},{"type":"type","title":"Wiki.Action.client_options/0","doc":"- `:accumulate` - Merge results from each step of a pipeline, rather than\n    overwriting with the latest response.\n  - `:adapter` - Override the HTTP adapter\n  - `:debug` - Turn on verbose logging by setting to `true`\n  - `:disable_compression` - Disable the transparent gzip codec, rather than\n    automatically detecting based on HTTP headers.\n  - `:user_agent` - Override the user-agent header string","ref":"Wiki.Action.html#t:client_options/0"},{"type":"module","title":"Wiki.Action.Session","doc":"This module provides a struct for holding private connection state and accumulated results.","ref":"Wiki.Action.Session.html"},{"type":"module","title":"Fields - Wiki.Action.Session","doc":"- `result` - Map with recursively merged values from all requests made using this session.\n- `state` - Cache for session state and accumulation.","ref":"Wiki.Action.Session.html#module-fields"},{"type":"type","title":"Wiki.Action.Session.client/0","doc":"","ref":"Wiki.Action.Session.html#t:client/0"},{"type":"type","title":"Wiki.Action.Session.result/0","doc":"","ref":"Wiki.Action.Session.html#t:result/0"},{"type":"type","title":"Wiki.Action.Session.state/0","doc":"","ref":"Wiki.Action.Session.html#t:state/0"},{"type":"type","title":"Wiki.Action.Session.t/0","doc":"","ref":"Wiki.Action.Session.html#t:t/0"},{"type":"module","title":"Wiki.EventStreams","doc":"This module reads from an infinite stream of [server-sent events](https://en.wikipedia.org/wiki/Server-sent_events)\nannotating actions such as editing or patrolling, as they happen on Wikimedia projects.\n\nFor more about the public wiki streams and their format, see\n[EventStreams on Wikitech](https://wikitech.wikimedia.org/wiki/EventStreams)","ref":"Wiki.EventStreams.html"},{"type":"module","title":"Examples - Wiki.EventStreams","doc":"Start reading the page creation feed, and expose as a GenStage.stream:\n\n```elixir\nWiki.EventStreams.start_link(streams: \"page-create\")\nWiki.EventStreams.stream()\n|> Stream.take(6)\n|> Enum.to_list\n```\n\nCombine multiple feeds,\n\n```elixir\nWiki.EventStreams.start_link(streams: [\"revision-create\", \"revision-score\"])\nWiki.EventStreams.stream()\n|> Stream.take(6)\n|> Enum.to_list\n```","ref":"Wiki.EventStreams.html#module-examples"},{"type":"module","title":"TODO - Wiki.EventStreams","doc":"* Currently only a single supervisor tree is supported, so calling applications can only read from one stream.\n* Track the restart ID, disconnect from the feed at some maximum queue size.  Reconnect as demand resumes.\nApplication-lifetime or permanent storage for the restart ID tracking, for consumers that need an at-least-once\nguarantee.","ref":"Wiki.EventStreams.html#module-todo"},{"type":"function","title":"Wiki.EventStreams.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Wiki.EventStreams.html#child_spec/1"},{"type":"function","title":"Wiki.EventStreams.start_link/1","doc":"Start a supervisor tree to receive and relay server-side events.","ref":"Wiki.EventStreams.html#start_link/1"},{"type":"function","title":"Arguments - Wiki.EventStreams.start_link/1","doc":"- `options` - Keyword list,\n  - `{:adapter, module}` - Override HTTPoison adapter.\n  - `{:endpoint, url}` - Override default endpoint.\n  - `{:send_to, pid | module}` - Instead of using the built-in streaming relay,\n  send the events directly to your own process.\n  - `{:streams, atom | [atom]}` - Select which streams to listen to.  An updated list can be\n  [found here](https://stream.wikimedia.org/?doc#/Streams).  Required.","ref":"Wiki.EventStreams.html#start_link/1-arguments"},{"type":"function","title":"Wiki.EventStreams.stream/1","doc":"Indefinitely capture subscribed events and relay them as a `Stream`.","ref":"Wiki.EventStreams.html#stream/1"},{"type":"type","title":"Wiki.EventStreams.client_option/0","doc":"","ref":"Wiki.EventStreams.html#t:client_option/0"},{"type":"type","title":"Wiki.EventStreams.client_options/0","doc":"* `:adapter` - Override the HTTP adapter.\n  * `:endpoint` - Override the default endpoint URL.\n  * `:stream_to` - Optional application which will receive the events, otherwise\n    they go to the process starting the EventStream.\n  * `:streams` - One or more atoms with the stream names to subscribe to.\n  * `:user_agent` - Custom user-agent header string","ref":"Wiki.EventStreams.html#t:client_options/0"},{"type":"module","title":"Wiki.Ores","doc":"This module provides an adapter for the [ORES](https://www.mediawiki.org/wiki/ORES) scoring service.","ref":"Wiki.Ores.html"},{"type":"module","title":"Examples - Wiki.Ores","doc":"```elixir\n\"enwiki\"\n|> Wiki.Ores.new()\n|> Wiki.Ores.request!(\n  models: [\"damaging\"],\n  revids: 456789\n)\n# %{\n#   \"enwiki\" => %{\n#     \"models\" => %{\n#       \"damaging\" => %{\"version\" => \"0.5.1\"}\n#     },\n#     \"scores\" => %{\n#       \"456789\" => %{\n#         \"damaging\" => %{\n#           \"score\" => %{\n#             \"prediction\" => false,\n#             \"probability\" => %{\n#               \"false\" => 0.9784615344695441,\n#               \"true\" => 0.021538465530455946\n#             }\n#           }\n#         }\n#       }\n#     }\n#   }\n# }\n```","ref":"Wiki.Ores.html#module-examples"},{"type":"function","title":"Wiki.Ores.new/2","doc":"Create a new ORES client.","ref":"Wiki.Ores.html#new/2"},{"type":"function","title":"Arguments - Wiki.Ores.new/2","doc":"- `project` - Short code for the wiki where your articles appear.  For example, \"enwiki\" for English Wikipedia.\n- `opts` - Configuration options that can change client behavior","ref":"Wiki.Ores.html#new/2-arguments"},{"type":"function","title":"Return value - Wiki.Ores.new/2","doc":"Returns an opaque client object, which should be passed to `request/2`.","ref":"Wiki.Ores.html#new/2-return-value"},{"type":"function","title":"Wiki.Ores.request/2","doc":"Make an ORES request.\n\nDon't request scores for more than 50 revisions per request.","ref":"Wiki.Ores.html#request/2"},{"type":"function","title":"Arguments - Wiki.Ores.request/2","doc":"- `client` - Client object as returned by `new/1`.\n- `params` - Keyword list of query parameters,\n  - `:models` - Learning models to query.  These vary per wiki, see the [support matrix](https://tools.wmflabs.org/ores-support-checklist/)\n  for availability and to read about what each model is scoring.  Multiple models can be passed as a list, for example,\n  `[:damaging, :wp10]`, or as a single atom, `:damaging`.\n  - `:revids` - Revision IDs to score, as a single integer or as a list.","ref":"Wiki.Ores.html#request/2-arguments"},{"type":"function","title":"Wiki.Ores.request!/2","doc":"Assertive variant of `request`.","ref":"Wiki.Ores.html#request!/2"},{"type":"type","title":"Wiki.Ores.client_option/0","doc":"","ref":"Wiki.Ores.html#t:client_option/0"},{"type":"type","title":"Wiki.Ores.client_options/0","doc":"- `:adapter` - Override the HTTP adapter\n  - `:debug` - Turn on verbose logging by setting to `true`\n  - `:endpoint` - Override the base URL to query\n  - `:user_agent` - Override the user-agent header string","ref":"Wiki.Ores.html#t:client_options/0"},{"type":"module","title":"Wiki.SiteMatrix","doc":"Retrieves sites from a wiki farm with the SiteMatrix extension installed.","ref":"Wiki.SiteMatrix.html"},{"type":"function","title":"Wiki.SiteMatrix.action_api/1","doc":"Get the Action API for a known site\n\n```elixir\nWiki.SiteMatrix.new()\n|> Wiki.SiteMatrix.get(\"enwiki\")\n|> Wiki.SiteMatrix.action_api()\n\n# \"https://en.wikipedia.org/w/api.php\"\n```\n\nAs a convenience, the site can be referenced as a bare string, in which case\nit will be looked up in the default Wikimedia farm.  Note that this will be\nuncached and so inappropriate for most production use.\n\n```elixir\nWiki.SiteMatrix.action_api(\"dewiki\")\n```","ref":"Wiki.SiteMatrix.html#action_api/1"},{"type":"function","title":"Arguments - Wiki.SiteMatrix.action_api/1","doc":"* `site` - Populated site structure.","ref":"Wiki.SiteMatrix.html#action_api/1-arguments"},{"type":"function","title":"Return value - Wiki.SiteMatrix.action_api/1","doc":"Calculated Action API.","ref":"Wiki.SiteMatrix.html#action_api/1-return-value"},{"type":"function","title":"Wiki.SiteMatrix.get/2","doc":"Look up a single site by key","ref":"Wiki.SiteMatrix.html#get/2"},{"type":"function","title":"Arguments - Wiki.SiteMatrix.get/2","doc":"* `sitematrix` - Result of Sitematrix.new()\n* `key` - The dbname (eg. \"enwiki\") or value of another key if specified as an\noption to new().","ref":"Wiki.SiteMatrix.html#get/2-arguments"},{"type":"function","title":"Return value - Wiki.SiteMatrix.get/2","doc":"Site spec or error","ref":"Wiki.SiteMatrix.html#get/2-return-value"},{"type":"function","title":"Wiki.SiteMatrix.get!/2","doc":"Assertive variant of `get`.","ref":"Wiki.SiteMatrix.html#get!/2"},{"type":"function","title":"Wiki.SiteMatrix.get_all/1","doc":"Get all sites for a wiki farm.","ref":"Wiki.SiteMatrix.html#get_all/1"},{"type":"function","title":"Arguments - Wiki.SiteMatrix.get_all/1","doc":"* `sitematrix` - Result of Sitematrix.new()","ref":"Wiki.SiteMatrix.html#get_all/1-arguments"},{"type":"function","title":"Return value - Wiki.SiteMatrix.get_all/1","doc":"List of site specifications.","ref":"Wiki.SiteMatrix.html#get_all/1-return-value"},{"type":"function","title":"Wiki.SiteMatrix.new/1","doc":"","ref":"Wiki.SiteMatrix.html#new/1"},{"type":"function","title":"Options - Wiki.SiteMatrix.new/1","doc":"- `api` - Action API URL for a site participating in the farm.\n  Defaults to https://meta.wikimedia.org/w/api.php.\n\n- `key_fun` - Function on a site spec, returning the key to build a lookup with,\n  later passed as the `key` argument to `get`.\n  Defaults to returning the site's `:dbname` (eg. \"enwiki\").","ref":"Wiki.SiteMatrix.html#new/1-options"},{"type":"type","title":"Wiki.SiteMatrix.client_options/0","doc":"","ref":"Wiki.SiteMatrix.html#t:client_options/0"},{"type":"opaque","title":"Wiki.SiteMatrix.sitematrix_state/0","doc":"","ref":"Wiki.SiteMatrix.html#t:sitematrix_state/0"},{"type":"module","title":"Wiki.SiteMatrix.Spec","doc":"Container for a single site.","ref":"Wiki.SiteMatrix.Spec.html"},{"type":"type","title":"Wiki.SiteMatrix.Spec.t/0","doc":"","ref":"Wiki.SiteMatrix.Spec.html#t:t/0"},{"type":"extras","title":"mediawiki-client notebook","doc":"# mediawiki-client notebook\n\n```elixir\nMix.install([\n  {:mediawiki_client, path: \"#{__DIR__}/..\"}\n])\n```","ref":"demo.html"},{"type":"extras","title":"Site matrix - mediawiki-client notebook","doc":"Any wiki farm (such as the default Wikimedia cluster) that includes the [SiteMatrix](https://www.mediawiki.org/wiki/Extension:SiteMatrix#API) extension exposes an API for fetching a list of all participating sites.  The Wiki.SiteMatrix module returns this full list,\n\n```elixir\nsite_matrix = Wiki.SiteMatrix.new()\n```\n\nYou can filter it by site if you already know its dbname (wiki database name).\n\n```elixir\ndewiki = Wiki.SiteMatrix.get!(site_matrix, \"dewiki\")\n```","ref":"demo.html#site-matrix"},{"type":"extras","title":"Working with a wiki - mediawiki-client notebook","doc":"You can pass a site spec to the initializer for other modules, or you can supply the base API URL if this is already known.\n\nFor the remainder of this notebook, we use the explicit site style so that the code blocks are self-contained and easy to copy and paste, and to make it more obvious how to target a local wiki.\n\n```elixir\nWiki.Action.new(dewiki) == Wiki.Action.new(\"https://de.wikipedia.org/w/api.php\")\n```","ref":"demo.html#working-with-a-wiki"},{"type":"extras","title":"Free-form Action API - mediawiki-client notebook","doc":"MediaWiki's main external interface is called the [Action API](https://www.mediawiki.org/wiki/API:Main_page), and this module allows access to any arbitrary command using keyword syntax:\n\n```elixir\n{:ok, %{result: %{\"query\" => %{\"babel\" => babel}}}} =\n  Wiki.Action.new(\"https://mediawiki.org/w/api.php\")\n  |> Wiki.Action.get(\n    action: :query,\n    meta: :babel,\n    babuser: \"Adamw\"\n  )\n\nbabel\n```","ref":"demo.html#free-form-action-api"},{"type":"extras","title":"Streaming continuation - mediawiki-client notebook","doc":"The Wiki.Action transparently handles continuation and can provide output as a stream.  This example snippet returns 50 results, making 10 calls with 5 results per call:\n\n```elixir\nWiki.Action.new(\"https://de.wikipedia.org/w/api.php\")\n|> Wiki.Action.stream(\n  action: :query,\n  list: :recentchanges,\n  rclimit: 5\n)\n|> Stream.take(10)\n|> Enum.flat_map(fn response -> response[\"query\"][\"recentchanges\"] end)\n|> Enum.map(fn rc -> rc[\"timestamp\"] <> \" \" <> rc[\"title\"] end)\n|> Enum.to_list()\n```","ref":"demo.html#streaming-continuation"},{"type":"extras","title":"Site statistics - mediawiki-client notebook","doc":"The [siteinfo](https://www.mediawiki.org/wiki/API:Siteinfo) API returns summary statistics for a wiki.\n\n```elixir\nWiki.Action.new(\"https://de.wikipedia.org/w/api.php\")\n|> Wiki.Action.get!(\n  action: :query,\n  meta: :siteinfo,\n  siprop: :statistics\n)\n|> Map.get(:result)\n```","ref":"demo.html#site-statistics"},{"type":"extras","title":"Event Streams - mediawiki-client notebook","doc":"You can monitor many different events in real-time using the [EventStreams](https://wikitech.wikimedia.org/wiki/Event_Platform/EventStreams) interface. These snippets sample from the most recent edits,\n\n```elixir\n{:ok, pid} = Wiki.EventStreams.start_link(streams: \"recentchange\")\n\nWiki.EventStreams.stream()\n|> Stream.take(6)\n|> Enum.each(fn event -> IO.inspect(event) end)\n\nProcess.exit(pid, :normal)\n```\n\nand from the feed of [ORES](https://www.mediawiki.org/wiki/ORES) results for recent edits,\n\n```elixir\n{:ok, pid} = Wiki.EventStreams.start_link(streams: \"revision-score\")\n\nWiki.EventStreams.stream()\n|> Stream.take(6)\n|> Enum.each(fn event -> IO.inspect(event) end)\n\nProcess.exit(pid, :normal)\n```","ref":"demo.html#event-streams"},{"type":"extras","title":"Machine learning scores - mediawiki-client notebook","doc":"To query ORES directly, use the Wiki.ORES module.  List the models available for your target wiki: (FIXME: eliminate the dummy request parameter)\n\n```elixir\nWiki.Ores.new(\"enwiki\")\n|> Wiki.Ores.request!(dummy: [])\n```\n\nRetrieve scores for multiple revisions by ID:\n\n```elixir\nWiki.Ores.new(\"enwiki\")\n|> Wiki.Ores.request!(\n  models: [:damaging, :wp10],\n  revids: [456_789, 123_456]\n)\n```","ref":"demo.html#machine-learning-scores"},{"type":"extras","title":"Wikidata - mediawiki-client notebook","doc":"Wikibase provides an Action API you can use as below.\n\nThis snippet runs a search:\n\n```elixir\nWiki.Action.new(\"https://www.wikidata.org/w/api.php\")\n|> Wiki.Action.get!(\n  action: :wbsearchentities,\n  search: \"alphabet\",\n  language: :en\n)\n|> Map.fetch(:result)\n```\n\nThis returns the detailed, structured data for a single Wikidata item:\n\n```elixir\nWiki.SiteMatrix.new()\n|> Wiki.SiteMatrix.get!(\"wikidatawiki\")\n|> Wiki.Action.new()\n|> Wiki.Action.get!(\n  action: :wbgetentities,\n  ids: \"Q42\"\n)\n|> Map.get(:result)\n```","ref":"demo.html#wikidata"},{"type":"extras","title":"Change log","doc":"# Change log\n\n## [Unreleased]\n\n## [0.4.8] - 2024-11","ref":"changelog.html"},{"type":"extras","title":"Added - Change log","doc":"- New option `key_fun` to build SiteMatrix lookup on an alternative key.  Wiki\nIDs are notoriously hard to standardize, so this change makes it easier o work\nwith data sets using alternate conventions eg. \"en.wikipedia\" or\n\"https://en.wikipedia.org/\" instead of the more canonical database name \"enwiki\"\nas ID.","ref":"changelog.html#added"},{"type":"extras","title":"Removed - Change log","doc":"- Drop support for end-of-life Elixir 1.11 and 1.12\n\n## [0.4.7] - 2024-04","ref":"changelog.html#removed"},{"type":"extras","title":"Fixed - Change log","doc":"- Upgrade dependencies, to unpin the mime dependency (bug #25).\n\n## [0.4.6] - 2023-11","ref":"changelog.html#fixed"},{"type":"extras","title":"Added - Change log","doc":"- Site struct carries opts, simplifying tests.\n- Include wiki `project` code in SiteMatrix specs.\n\n## [0.4.5] - 2023-09","ref":"changelog.html#added"},{"type":"extras","title":"Added - Change log","doc":"- New adapter option `:disable_compression`. ([#14](https://gitlab.com/adamwight/mediawiki_client_ex/-/merge_requests/14)) (Wenzel)","ref":"changelog.html#added"},{"type":"extras","title":"Fixed - Change log","doc":"- Authenticated usage no longer requires empty initial cookies. ([#14](https://gitlab.com/adamwight/mediawiki_client_ex/-/merge_requests/14)) (Wenzel)\n\n## [0.4.4] - 2023-09","ref":"changelog.html#fixed"},{"type":"extras","title":"Fixed - Change log","doc":"- Robustly handle missing group names.\n\n## [0.4.3] - 2023-04","ref":"changelog.html#fixed"},{"type":"extras","title":"Changed - Change log","doc":"- Action API timeout extended from 5 to 60 seconds.\n- Changelog reformatted according to the [Common Changelog](https://common-changelog.org/) style.\n\n## [0.4.2] - 2023-03","ref":"changelog.html#changed"},{"type":"extras","title":"Changed - Change log","doc":"- **Breaking:** Require Elixir 1.11","ref":"changelog.html#changed"},{"type":"extras","title":"Added - Change log","doc":"- Add a Livebook example notebook\n\n## [0.4.1] - 2022-12","ref":"changelog.html#added"},{"type":"extras","title":"Added - Change log","doc":"- Now compatible with tesla ~>1.5","ref":"changelog.html#added"},{"type":"extras","title":"Fixed - Change log","doc":"- Fix compression for Action and ORES APIs\n\n## [0.4.0] - 2022-09","ref":"changelog.html#fixed"},{"type":"extras","title":"Changed - Change log","doc":"- **Breaking:** Wiki.EventStreams `:send_to` option renamed to `:stream_to`.\n- `mix test.all` task replaces git\\_hooks for development.","ref":"changelog.html#changed"},{"type":"extras","title":"Removed - Change log","doc":"- **Breaking:** Config variables are deprecated, all customization is done via keyword options.\n\n## [0.3.1] - 2022-09","ref":"changelog.html#removed"},{"type":"extras","title":"Changed - Change log","doc":"- **Breaking:** Wiki.Site renamed to Wiki.SiteMatrix and has an updated interface.  `new()` returns an opaque sitematrix.\n- **Breaking:** Settle on the Apache 2 license (bug #21).","ref":"changelog.html#changed"},{"type":"extras","title":"Added - Change log","doc":"- Wiki.SiteMatrix caches the response.\n\n## [0.3.0] - 2021-12","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Change log","doc":"- **Breaking:** Switched most of the API to return `{:ok | :error, ...}` tuples.  For quick migration just use the bang functions like `get!`.  Or match `{:ok, result}` for fine-grained error handling.  Errors will be returned as exception objects, with a crude string message for now.  In a future release these will include a reason atom.\n\n## [0.2.6] - 2021-12","ref":"changelog.html#changed"},{"type":"extras","title":"Changed - Change log","doc":"- **Breaking:** Renamed the package from `wiki_elixir` to `mediawiki_client`.  `mix.exs` dependencies must be updated.  The package namespace is still `Wiki.`-, because I honor your labors, gentle reader.\n- **Breaking:** OTP app name in configuration must also be changed from `wiki_elixir` to `mediawiki_client`.\n\n## [0.2.5] - 2021-11","ref":"changelog.html#changed"},{"type":"extras","title":"Changed - Change log","doc":"- You may migrate `Wiki.Action.new()` calls to accept a `Wiki.Site` object, which will be used to calculate the default endpoint.","ref":"changelog.html#changed"},{"type":"extras","title":"Added - Change log","doc":"- `Wiki.Site` module for retrieving the Wikimedia site matrix.\n\n## [0.2.2] - 2021-11","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Change log","doc":"- Depend on eventsource\\_ex library, testability improvements have been upstreamed.","ref":"changelog.html#changed"},{"type":"extras","title":"Added - Change log","doc":"- Continuous tests verify compatibility with Elixir 1.9-1.12 .","ref":"changelog.html#added"},{"type":"extras","title":"Removed - Change log","doc":"- Drop unused dependencies.","ref":"changelog.html#removed"},{"type":"extras","title":"Fixed - Change log","doc":"- User-agent header sends correct library version.\n\n## [0.2.1] - 2021-05","ref":"changelog.html#fixed"},{"type":"extras","title":"Changed - Change log","doc":"- **Breaking:** Request query parameters are passed as a keyword list rather than a map.\n- **Breaking:** Handles application-level API errors in the action and ores apis, failing fast.\n- Default to action response format version 2.","ref":"changelog.html#changed"},{"type":"extras","title":"Added - Change log","doc":"- Complete test coverage for both happy and sad cases.","ref":"changelog.html#added"},{"type":"extras","title":"Removed - Change log","doc":"- Remove unused `Timex` dependency.","ref":"changelog.html#removed"},{"type":"extras","title":"Fixed - Change log","doc":"- Allow literal \"|\" in parameters by switching the delimiter to \"unit separator\".\n\n## [0.1.4] - 2020-05","ref":"changelog.html#fixed"},{"type":"extras","title":"Added - Change log","doc":"- Some test coverage for `Wiki.Action`.\n- Add lint jobs to git hook and GitLab CI.","ref":"changelog.html#added"},{"type":"extras","title":"Removed - Change log","doc":"- **Breaking:** Removed the incomplete `Wiki.Rest` client.","ref":"changelog.html#removed"},{"type":"extras","title":"Fixed - Change log","doc":"- Fix application configuration bug, nothing worked out of the box.\n- Fix a continuation bug which would drop the first response.\n\n## [0.1.2] - 2020-05","ref":"changelog.html#fixed"},{"type":"extras","title":"Changed - Change log","doc":"- **Breaking:** Rename WikiAction -> `Wiki.Action`\n- **Breaking:** Rename WikiRest -> `Wiki.Rest`\n- **Breaking:** Rename WikiSSE -> `Wiki.EventStreams`","ref":"changelog.html#changed"},{"type":"extras","title":"Added - Change log","doc":"- Basic ORES client.\n- Inline examples included in module documentation.\n- Pipe-join list values for Action API.\n- Accumulate Action results.\n\n## [0.1.1] - 2020-05","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Change log","doc":"- Simplify and package examples as scripts.\n- Host code on GitLab, apply the most basic CI.\n- Temporarily inline the [cwc/eventsource\\_ex](https://github.com/cwc/eventsource_ex/) server-side events library as a workaround.\n- Switch to Tesla HTTP client.","ref":"changelog.html#changed"},{"type":"extras","title":"Added - Change log","doc":"- Send User-Agent header.\n- Action API and continuations.  Authentication, session cookies.\n- Pipelining.\n- Flexible endpoint.\n- Server-side events relayed as a `Stream`.\n- Begin work on REST API.\n\n## [0.1.0] - 2019-05\n\n_Initial release._\n\n[Unreleased]: https://gitlab.com/adamwight/mediawiki_client_ex/-/compare/v0.4.8...HEAD\n[0.4.8]: https://gitlab.com/adamwight/mediawiki_client_ex/-/compare/v0.4.7...v0.4.8\n[0.4.7]: https://gitlab.com/adamwight/mediawiki_client_ex/-/compare/v0.4.6...v0.4.7\n[0.4.6]: https://gitlab.com/adamwight/mediawiki_client_ex/-/compare/v0.4.5...v0.4.6\n[0.4.5]: https://gitlab.com/adamwight/mediawiki_client_ex/-/compare/v0.4.4...v0.4.5\n[0.4.4]: https://gitlab.com/adamwight/mediawiki_client_ex/-/compare/v0.4.3...v0.4.4\n[0.4.3]: https://gitlab.com/adamwight/mediawiki_client_ex/-/compare/v0.4.2...v0.4.3\n[0.4.2]: https://gitlab.com/adamwight/mediawiki_client_ex/-/compare/v0.4.1...v0.4.2\n[0.4.1]: https://gitlab.com/adamwight/mediawiki_client_ex/-/compare/v0.4.0...v0.4.1\n[0.4.0]: https://gitlab.com/adamwight/mediawiki_client_ex/-/compare/v0.3.1...v0.4.0\n[0.3.1]: https://gitlab.com/adamwight/mediawiki_client_ex/-/compare/v0.3.0...v0.3.1\n[0.3.0]: https://gitlab.com/adamwight/mediawiki_client_ex/-/compare/v0.2.6...v0.3.0\n[0.2.6]: https://gitlab.com/adamwight/mediawiki_client_ex/-/compare/v0.2.5...v0.2.6\n[0.2.5]: https://gitlab.com/adamwight/mediawiki_client_ex/-/compare/v0.2.2...v0.2.5\n[0.2.2]: https://gitlab.com/adamwight/mediawiki_client_ex/-/compare/v0.2.1...v0.2.2\n[0.2.1]: https://gitlab.com/adamwight/mediawiki_client_ex/-/compare/v0.1.4...v0.2.1\n[0.1.4]: https://gitlab.com/adamwight/mediawiki_client_ex/-/compare/v0.1.2...v0.1.4\n[0.1.2]: https://gitlab.com/adamwight/mediawiki_client_ex/-/compare/v0.1.1...v0.1.2\n[0.1.1]: https://gitlab.com/adamwight/mediawiki_client_ex/-/compare/v0.1.0...v0.1.1\n[0.1.0]: https://gitlab.com/adamwight/mediawiki_client_ex/-/tags/v0.1.0","ref":"changelog.html#added"},{"type":"extras","title":"MediaWiki client","doc":"# MediaWiki client\n\nUnofficial client modules for connecting to Wikipedia, Wikidata, and other MediaWiki sites from Elixir code.  Supports multiple APIs: Action, EventStreams, and Scoring.\n\nAPI reference for the current version: [Documentation and examples](https://hexdocs.pm/mediawiki_client/api-reference.html)\n\nOverview:\n* `Wiki.Action` is the primary read/write interface for wikis, connecting to the\n[Action API](https://www.mediawiki.org/wiki/Special:MyLanguage/API:Main_page).\nThis is a rich set of commands to query or edit almost anything on a wiki.\n* `Wiki.EventStreams` is a real-time\n[EventStreams](https://wikitech.wikimedia.org/wiki/Event_Platform/EventStreams)\nfeed allowing an application to process edits as they happen.\n* `Wiki.Ores` is a [scoring service](https://www.mediawiki.org/wiki/ORES)\nfor estimating revision and edit quality.","ref":"readme.html"},{"type":"extras","title":"Installation - MediaWiki client","doc":"Install this package by adding `mediawiki_client` to your dependencies in `mix.exs`,\n\n```elixir\ndef deps do\n  [\n    {:mediawiki_client, \"~> 0.4.0\"}\n  ]\nend\n```\n\nDocumentation is generated with `mix docs`.","ref":"readme.html#installation"},{"type":"extras","title":"Updating - MediaWiki client","doc":"Please see the [change log](CHANGELOG.md) for a history of breaking changes.\nThis library is still pre-1.0 and open to improvement.","ref":"readme.html#updating"},{"type":"extras","title":"Livebook examples - MediaWiki client","doc":"An [Livebook](https://livebook.dev/) notebook is included to demonstrate usage.\n\n```\nlivebook server notebooks/demo.livemd\n```","ref":"readme.html#livebook-examples"},{"type":"extras","title":"Quick start - MediaWiki client","doc":"Fetch some statistics about German Wikipedia,\n\n```elixir\nWiki.SiteMatrix.new()\n|> Wiki.SiteMatrix.get!(\"dewiki\")\n|> Wiki.Action.new()\n|> Wiki.Action.get!(\n  action: :query,\n  meta: :siteinfo,\n  siprop: :statistics\n)\n# %Wiki.Action.Session{\n#   ...\n#   result: %{\n#     \"batchcomplete\" => true,\n#     \"query\" => %{\n#       \"statistics\" => %{\n#         \"activeusers\" => 19687,\n#         \"admins\" => 188,\n#         \"articles\" => 2583285,\n#         \"edits\" => 211219883,\n#         \"images\" => 130199,\n#         \"jobs\" => 0,\n#         \"pages\" => 7163473,\n#         \"queued-massmessages\" => 0,\n#         \"users\" => 3715461\n#       }\n#     }\n#   },\n#   ...\n# }\n```\n\nAdditional examples are included in the [source documentation](https://hexdocs.pm/mediawiki_client/api-reference.html) .","ref":"readme.html#quick-start"},{"type":"extras","title":"Error handling - MediaWiki client","doc":"Most methods come in an assertive and a non-assertive form, for example the\n`Wiki.Action.get()` method returns an `{:ok, ...}` or a `{:error, ...}` tuple, and\n`Wiki.Action.get!()` throws the error directly.","ref":"readme.html#error-handling"},{"type":"extras","title":"Development - MediaWiki client","doc":"The [project homepage](https://gitlab.com/adamwight/mediawiki_client_ex) is on GitLab.\nTo contribute, feel free to start with an issue, push a merge request, or\ncontact maintainers.\n\nTo run all tests,\n```shell\nmix test.all\n```\n\nTo generate a test [coverage report](../cover/excoveralls.html),\n```shell\nmix coveralls.html\n```","ref":"readme.html#development"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}